@@ -32,15 +32,15 @@ def clean_data(string):
     string = re.sub(' c/o.*', '', string) # Remove care of
 
 
-    string = re.sub(" corporation(\s|$)", " corp\\1", string) # shorten corporation to corp
-    string = re.sub(" company(\s|$)", " co\\1", string) # shorten company to co
-    string = re.sub(" maa?nage?ment(\s|$)", " mgmt\\1", string)  # etc
-    string = re.sub(" incorporated(\s|$)", " inc\\1", string)
-    string = re.sub(" apartments(\s|$)", " apts\\1", string)
-    string = re.sub( " square(\s|$)", " sq\\1", string)
-    string = re.sub(" redevelopment and housing authority(\s|$)", " rha\\1", string) 
-    string = re.sub(" redevelopment and housing auth\.?(\s|$)", " rha\\1", string) 
-    string = re.sub(" redevelopment and housing(\s|$)", " rha\\1", string) 
+    string = re.sub(" corporation", " corp", string) # shorten corporation to corp
+    string = re.sub(" company", " co", string) # shorten company to co
+    string = re.sub(" maa?nage?ment", " mgmt", string)  # etc
+    string = re.sub(" incorporated", " inc", string)
+    string = re.sub(" apartments", " apts", string)
+    string = re.sub( " square(\s|$|,)", " sq\\1", string)
+    string = re.sub("redevelopment and housing authority", "rha", string) 
+    string = re.sub("redevelopment and housing auth\.?", "rha", string) 
+    string = re.sub("redevelopment and housing", "rha", string) 
     
 
     string = re.sub(" et\.?\s?al\.?$", "", string)
