@@ -1,17 +1,11 @@
-from sklearn.metrics.pairwise import cosine_similarity
 from sklearn.feature_extraction.text import TfidfVectorizer
-import re
 import pandas as pd
-from cleancourt.compute_ngrams import ngrams
 from loguru import logger
 from sklearn.neighbors import NearestNeighbors
-import time
-import numpy as np
-from tqdm import tqdm
-from cleancourt.integrate_output import map_values
-import json
-from cleancourt.filter_types import filter_companies
 
+from cleancourt.compute_ngrams import ngrams
+from cleancourt.filter_types import filter_companies
+from cleancourt.clean_data import clean_data
 
 
 
@@ -30,7 +24,7 @@ def _print_matches(distances, indices, org_name_messy, org_name_clean):
 
 
 
-def compare_companies(org_name_messy, org_name_clean, threshold = SIMILARITY_DISTANCE, print_all_matches = False):
+def compare_companies(org_name_messy, org_name_clean, threshold = SIMILARITY_DISTANCE, print_all_matches = False, clean_org_names = [False, False]):
     '''This method implements a K-Nearest Neighbors (KNN) algorithm to
     compare a standard list of *clean* party names to a *messy* list of
     party names. 
@@ -42,9 +36,18 @@ def compare_companies(org_name_messy, org_name_clean, threshold = SIMILARITY_DIS
 
     '''
 
+
+
     # Remove people from the list of names
     org_name_messy = [name for name in org_name_messy if filter_companies(name)]
 
+    # Clean data in both lists if optional parameters are set to true
+    if(clean_org_names[0]):
+        logger.info("Cleaning Messy Org Dataset")
+        org_name_messy = [clean_data(name) for name in org_name_messy]
+    if(clean_org_names[1]):
+        logger.info("Cleaning Clean Org Dataset")
+        org_name_clean = [clean_data(name) for name in org_name_clean]
 
     logger.info("Vectorizing and Transforming Clean Names")
 
